@@ -11,7 +11,7 @@ from matplotlib.pyplot import rcParams,figure,show,draw
 from matplotlib.ticker import MultipleLocator, FormatStrFormatter
 
 from thermodynamics import VirtualTemp,Latentc,SatVap,MixRatio,GammaW,\
-    VirtualTempFromMixR,MixR2VaporPress,DewPoint,Theta,TempK,Density,DensityHumid
+    VirtualTempFromMixR,MixR2VaporPress,DewPoint,Theta,TempK,Density,DensHumid
 from thermodynamics import Rs_da, Cp_da, Epsilon,degCtoK
 
 
@@ -19,7 +19,7 @@ from UserDict import UserDict
 from datetime import datetime
 import os,sys
 
-__version__="0.1.4"
+__version__="0.1.5"
 
 class SkewXTick(maxis.XTick):
     #Copyright (c) 2008 Ryan May
@@ -175,24 +175,27 @@ class SkewXAxes(Axes):
     def drag_pan(self, button, key, x, y):
         pass
 
-    def other_housekeeping(self,pmin=100.,mixratio=array([])):
+    def other_housekeeping(self,mixratio=array([])):
         # Added by Thomas Chubb
         self.yaxis.grid(True,ls='-',color='y',lw=0.5)
 
+        pmax=self.pmax
+        pmin=self.pmin
+
         # Plot x-grid lines instead of using xaxis.grid().
         # This is because xaxis.grid only plots skew lines 
         # that intersect the lower x axis... a possible fix
         # would be to use twinx() to plot upper and lower
         # grid lines but I think that's messy too.
         for TT in linspace(-100,100,21):
-            self.plot([TT,TT],[1050,pmin],color='y',lw=0.5)
+            self.plot([TT,TT],[pmax,pmin],color='y',lw=0.5)
 
         # self.set_ylabel('Pressure (hPa)')
         self.set_xlabel('Temperature (C)')
         self.set_yticks(linspace(100,1000,10))
         self.yaxis.set_major_formatter(ScalarFormatter())
         self.set_xlim(-40,30)
-        self.set_ylim(1050.,pmin)
+        self.set_ylim(pmax,pmin)
         self.spines['right'].set_visible(False)
         self.get_yaxis().set_tick_params(which="both",size=0)
         self.get_xaxis().set_tick_params(which="both",size=0)
@@ -295,7 +298,7 @@ class Sounding(UserDict):
 
         if data is None:
             self.data={}
-            self.readfile(filename)
+            self.uwyofile(filename)
         else:
             self.data=data
             if not data.has_key("SoundingDate"):
@@ -303,10 +306,10 @@ class Sounding(UserDict):
             if not data.has_key("StationNumber"):
                 self["StationNumber"]="(no number)"
 
-    def plot_skewt(self, imagename=None, title=None, **kwargs):
+    def plot_skewt(self,pmax=1050.,pmin=100., imagename=None, title=None, **kwargs):
         """A wrapper for plotting the skewt diagram for a Sounding instance."""
         
-        self.make_skewt_axes()
+        self.make_skewt_axes(pmax,pmin)
         self.add_profile(**kwargs)
         parcel=self.surface_parcel()
         self.lift_parcel(*parcel)
@@ -330,9 +333,9 @@ class Sounding(UserDict):
         >>>
         S=SkewT.Sounding(data={})
         S.make_skewt_axes()
-        S.readfile("../examples/94975.2013062800.txt")
+        S.uwyofile("../examples/94975.2013062800.txt")
         S.add_profile(color="b",bloc=0.5)
-        S.readfile("../examples/94975.2013070900.txt")
+        S.uwyofile("../examples/94975.2013070900.txt")
         S.add_profile(color="r",bloc=1.)
         >>>
         Use the kwarg 'bloc' to set the alignment of the wind barbs from 
@@ -352,7 +355,7 @@ class Sounding(UserDict):
         try: 
             pres = ma.masked_invalid(self.data['pres'])
         except KeyError: 
-            raise KeyError, "Temperature in hPa (PRES) is required!"
+            raise KeyError, "Pres in hPa (PRES) is required!"
 
         try: 
             tc=ma.masked_invalid(self.data['temp'])
@@ -403,9 +406,11 @@ class Sounding(UserDict):
         return tcprof
 
     def make_skewt_axes(self,pmax=1050.,pmin=100.):
+        """Set up the skew-t axis the way I like to see it"""
         
         self.fig = figure(figsize=(8,8))
         self.fig.clf()
+
         
         rcParams.update({\
             'font.size':10,\
@@ -413,6 +418,8 @@ class Sounding(UserDict):
 
         self.skewxaxis=self.fig.add_axes([.065,.1,.71,.8], projection='skewx')
         self.skewxaxis.set_yscale('log')
+        self.skewxaxis.pmax=pmax
+        self.skewxaxis.pmin=pmin
 
         xticklocs=arange(-80,45,10)
         T0 = xticklocs
@@ -436,6 +443,7 @@ class Sounding(UserDict):
         self.wbax.get_yaxis().set_tick_params(size=0,color='y')
         self.wbax.set_xlim(-1.5,1.5)
         self.wbax.get_yaxis().set_visible(False)
+        self.wbax.set_title('kn',fontsize=10,color='k',ha='right')
 
         # Set up standard atmosphere height scale on 
         # LHS of plot. 
@@ -443,12 +451,18 @@ class Sounding(UserDict):
         majorLocatorKFT  = MultipleLocator(5)
         minorLocator     = MultipleLocator(1)
 
+        # determine base height from base pressure (nominally 1050 hPa)
+        # via hydrostatic equilibrium for standard atmosphere
+
+        zmin=-(pmax-1013.25)*288*Rs_da /(1013.25*9.8)
+        zminf=zmin*3.2808
+
         self.kmhax=self.fig.add_axes([0.775,0.1,1e-6,0.8],frameon=True)
         self.kmhax.xaxis.set_ticks([],[])
         self.kmhax.spines['left'].set_color('k')
         self.kmhax.spines['right'].set_visible(False)
         self.kmhax.tick_params(axis='y', colors='k',labelsize=8)
-        self.kmhax.set_ylim(0,16.18)
+        self.kmhax.set_ylim(zmin*1e-3,16.18)
         self.kmhax.set_title("km/kft",fontsize=10)
         self.kmhax.get_yaxis().set_tick_params(which="both",direction='out')
         self.kmhax.yaxis.set_major_locator(majorLocatorKM)
@@ -457,29 +471,49 @@ class Sounding(UserDict):
         self.fthax=self.kmhax.twinx()
         self.fthax.xaxis.set_ticks([],[])
         self.fthax.tick_params(axis='y', colors='k',labelsize=8)
-        self.fthax.set_ylim(0,53.084)
+        self.fthax.set_ylim(zminf*1e-3,53.084)
         self.fthax.get_yaxis().set_tick_params(which="both",direction='out')
         self.fthax.yaxis.set_major_locator(majorLocatorKFT)
         self.fthax.yaxis.set_minor_locator(minorLocator)
 
-    def readfile(self,fname):
+    def uwyofile(self,fname):
+        """Reads the raw profile data from a Universiy of Wyoming sounding file.
+
+        This is the primary method of IO for SkewT. The University of 
+        Wyoming maintains a nice database of global upper air data which is
+        kept up-to-date. Given a filename, this method updates the sounding 
+        data with the text data in the file.
+
+        NOTES
+        1. The input file has to conform *Exactly* to the University of 
+           Wyoming file format. This is because I look for data fields at 
+           specific places on each line.
+        2. I ignore the diagnostics at the end of the file, because the idea 
+           is to calculate these myself.
+        """
         #--------------------------------------------------------------------
         # This *should* be a convenient way to read a uwyo sounding
         #--------------------------------------------------------------------
         fid=open(fname)
         lines=fid.readlines()
         nlines=len(lines)
-        ndata=nlines-34
+
+        lhi=[1, 9,16,23,30,37,46,53,58,65,72]
+        rhi=[7,14,21,28,35,42,49,56,63,70,77]
+
+
+        # initialise output data structure
         output={}
 
         fields=lines[3].split()
         units=lines[4].split()
 
+        # Handle the file header
         # First line for WRF profiles differs from the UWYO soundings
         header=lines[0]
         if header[:5]=='00000':
             # WRF profile
-            self['StationNumber']='-99999'
+            self['StationNumber']='00000'
             self['Longitude']=float(header.split()[5].strip(","))
             self['Latitude']=float(header.split()[6])
             self['SoundingDate']=header.split()[-1]
@@ -488,29 +522,44 @@ class Sounding(UserDict):
             dstr=(' ').join(header.split()[-4:])
             self['SoundingDate']=datetime.strptime(dstr,"%HZ %d %b %Y").strftime("%Y-%m-%d_%H:%M:%S") 
 
+        # This is a data pre-initialisation step. I have used the number of lines minus the number
+        # of lines of diagnostics.
         for ff in fields:
-            output[ff.lower()]=zeros((nlines-34))-999.
-
-        lhi=[1, 9,16,23,30,37,46,53,58,65,72]
-        rhi=[7,14,21,28,35,42,49,56,63,70,77]
+            # output[ff.lower()]=zeros((nlines-34))-999.
+            output[ff.lower()]=[]
 
         lcounter=5
-        for line,idx in zip(lines[6:],range(ndata)):
+        for line,idx in zip(lines[6:],range(nlines)):
             lcounter+=1
+            ### Version < 0.1.4
+            # try: output[fields[0].lower()][idx]=float(line[lhi[0]:rhi[0]])
+            # except ValueError: break
 
-            try: output[fields[0].lower()][idx]=float(line[lhi[0]:rhi[0]])
-            except ValueError: break
+            ### New code. We test for pressure in the first column. 
+            ### If there's no pressure, we get out!
+            try: 
+                output[fields[0].lower()].append(float(line[lhi[0]:rhi[0]]))
+            except ValueError: 
+                break
             
             for ii in range(1,len(rhi)):
                 try: 
                     # Debug only:
                     # print fields[ii].lower(), float(line[lhi[ii]:rhi[ii]].strip())
-                    output[fields[ii].lower()][idx]=float(line[lhi[ii]:rhi[ii]].strip())
+                    ### Version < 0.1.4
+                    # output[fields[ii].lower()][idx]=float(line[lhi[ii]:rhi[ii]].strip())
+                     
+                    ### New Code. Append to list instead of indexing 
+                    ### pre-allocated data. Explicitly allocate -999
+                    ### for invalid data (catch ValueError)
+                    textdata=line[lhi[ii]:rhi[ii]].strip()
+                    output[fields[ii].lower()].append(float(textdata))
                 except ValueError: 
-                    pass
+                    output[fields[ii].lower()].append(-999.)
 
         for field in fields:
             ff=field.lower()
+            # set mask for missing data
             self.data[ff]=ma.masked_values(output[ff],-999.)
 
         return None
@@ -550,7 +599,7 @@ class Sounding(UserDict):
         mixrkg=MixRatio(vprespa,prespa)
 
         # Calculate density of air (accounting for moisture)
-        rho=DensityHumid(tempk,prespa,vprespa)
+        rho=DensHumid(tempk,prespa,vprespa)
 
         # Trapezoidal rule to approximate TPW (units kg/m^2==mm)
         tpw=trapz(mixrkg*rho,hghtm)
@@ -684,19 +733,31 @@ def lift_wet(startt,pres):
     return t_out
 
 
+
+
+
 if __name__=='__main__':
 
     if len(sys.argv)==1 or sys.argv[1]=="example":
         # Do the examples in the "examples" directory
-        examples=("2013070200","2013070900",)
+        examples=("94975.2013070200","94975.2013070900")
         parcels=((1004.,17.4,8.6),(1033.,10.7,-0.9),)
         for ex,pc in zip(examples,parcels):
-            sounding=Sounding("../examples/94975.%s.txt"%ex)
+            sounding=Sounding("./examples/%s.txt"%ex)
             sounding.make_skewt_axes()
             sounding.add_profile(color='r',lw=2)
             sounding.lift_parcel(*pc)
             sounding.column_diagnostics()
-            sounding.fig.savefig("../examples/94975.%s.png"%ex)
+            # sounding.fig.savefig("./examples/%s.png"%ex)
+
+        examples=("bna_day1","bna_day2")
+        for ex in examples:
+            sounding=Sounding("./examples/%s.txt"%ex)
+            sounding.plot_skewt()
+            # sounding.fig.savefig("./examples/%s.png"%ex)
+
+
+
     else:
         sounding=Sounding(sys.argv[1])
         sounding.plot_skewt(color='r')
