@@ -40,12 +40,12 @@ def Theta(tempk,pres,pref=100000.):
     """
 
     try:
-	minpres=min(pres)
+        minpres=min(pres)
     except TypeError:
-	minpres=pres
+        minpres=pres
 
     if minpres<2000:
-	print "WARNING: P<2000 Pa; did you input a value in hPa?"
+        print "WARNING: P<2000 Pa; did you input a value in hPa?"
 
     return tempk*(pref/pres)**(Rs_da/Cp_da)
 
@@ -53,12 +53,12 @@ def TempK(theta,pres,pref=100000.):
     """Inverts Theta function."""
 
     try:
-	minpres=min(pres)
+        minpres=min(pres)
     except TypeError:
-	minpres=pres
+        minpres=pres
 
     if minpres<2000:
-	print "WARNING: P<2000 Pa; did you input a value in hPa?"
+        print "WARNING: P<2000 Pa; did you input a value in hPa?"
 
     return theta*(pres/pref)**(Rs_da/Cp_da)
 
@@ -99,8 +99,8 @@ def GammaW(tempk,pres,e=None):
     ws=MixRatio(es,pres)
 
     if e is None:
-	# assume saturated
-	e=es
+        # assume saturated
+        e=es
 
     w=MixRatio(e,pres)
 
@@ -113,9 +113,9 @@ def GammaW(tempk,pres,e=None):
     Gamma=(A/B)/(Cp_da*Rho)
     return Gamma
 
-def DensityHumid(tempk,pres,e):
+def DensHumid(tempk,pres,e):
     """Density of moist air.
-    This is a bit more explicit ant less confusing than the method below.
+    This is a bit more explicit and less confusing than the method below.
 
     INPUTS:
     tempk: Temperature (K)
@@ -227,13 +227,13 @@ def SatVap(tempc,phase="liquid"):
     # return where(tempc<0,over_ice,over_liquid)
 
     if phase=="liquid":
-	# return 6.112*exp(17.67*tempc/(tempc+243.12))*100.
-	return over_liquid
+        # return 6.112*exp(17.67*tempc/(tempc+243.12))*100.
+        return over_liquid
     elif phase=="ice":
-	# return 6.112*exp(22.46*tempc/(tempc+272.62))*100.
-	return where(tempc<0,over_ice,over_liquid)
+        # return 6.112*exp(22.46*tempc/(tempc+272.62))*100.
+        return where(tempc<0,over_ice,over_liquid)
     else:
-	raise NotImplementedError
+        raise NotImplementedError
 
 def MixRatio(e,p):
     """Mixing ratio of water vapour
